@@ -1129,6 +1129,22 @@ class Base_Page(Borg, unittest.TestCase):
             self.exceptions.append("An exception occurred when scrolling down")
             return False
 
+    def key_press_HOME(self, locator, wait_time=0.5):
+        try:
+            element = self.get_element(locator)
+            element.send_keys(Keys.HOME)
+            self.wait(wait_time)
+            return True
+        except Exception as e:
+            self.write(str(e), 'debug')
+            self.exceptions.append("An exception occurred when scrolling down")
+            return False
+
+    def scroll_to_top_by_js(self):
+        top = self.execute_javascript_with_return("window.pageYOffset")
+        cmd = "window.scrollBy(0, -%s)" % top
+        self.execute_javascript(cmd)
+
     def hover(self, locator, wait_seconds=0.5):
         "Hover over the element"
         # Note: perform() of ActionChains does not return a bool
@@ -1367,15 +1383,14 @@ class Base_Page(Borg, unittest.TestCase):
 
     def scroll_to_dom_element_by_js(self, element, wait_time=1):
         """Assume window inner height is larger than element height
-        Do nothing if the element already on screen
         Will screen down until the element display in the middle of windows
         Default Wait 1 second after calling js.
         ***Please be careful next operation will be executed while scrolling"""
         y = element.location.get("y")
         top = self.execute_javascript_with_return("window.pageYOffset")
         window = self.execute_javascript_with_return("window.innerHeight")
-        if self.check_dom_element_is_display_on_screen_by_yaxis_and_js(element):
-            return
+        # if self.check_dom_element_is_display_on_screen_by_yaxis_and_js(element):  # Remove checking because some overlay header in website will block the element
+        #     return
         if y > top:
             cmd = "window.scrollBy(0, %s)" % str((y-top)-(window/2))
         else:
@@ -1383,4 +1398,12 @@ class Base_Page(Borg, unittest.TestCase):
         self.execute_javascript(cmd)
         self.wait(wait_time)
 
+    def scroll_to_dom_element_by_js(self, locator, wait_time=1):
+        """If locator have multiple elements, will scroll to 1st element
+        Assume window inner height is larger than element height
+        Will screen down until the element display in the middle of windows
+        Default Wait 1 second after calling js.
+        ***Please be careful next operation will be executed while scrolling"""
+        self.scroll_to_dom_element_by_js(self.get_element(locator))
+
     # _get_locator = staticmethod(_get_locator) "COMMENT BECAUSE _get_locator commented"
